@@ -1,8 +1,10 @@
 __title__ = "pydumpck"
 __description__ = "a pyfile decomplier base on pycdc for windows."
-__keywords__ = ('pydumpck', 'decomplier', 'pe', 'elf', 'pyc', 'pyz')
+__keywords__ = ['pydumpck', 'decomplier', 'pe', 'elf', 'pyc', 'pyz']
 __url__ = "https://github.com/serfend/pydumpck"
-__version__ = "1.1.8"
+__version__ = "1.1.9"
 __author__ = "serfend"
 __author_email__ = "serfend@foxmail.com"
-__license__ = "MIT Licence"
\ No newline at end of file
+__license__ = "MIT Licence"
+
+__public_path__ = './dist'
\ No newline at end of file
